@@ -189,6 +189,12 @@ gksu_ask_password (gchar *title, gchar *message, gboolean grab)
   /* dialog window */
   dialog = gksuui_dialog_new ();
 
+  if(title != NULL)
+     gtk_window_set_title(GTK_WINDOW(dialog), title);
+  if(message != NULL)
+     gksuui_dialog_set_message(GKSUUI_DIALOG(dialog), message);
+
+  gtk_window_set_keep_above(dialog, TRUE);
   gtk_widget_show_all (dialog);
 
   while (gtk_events_pending())
